遗愿清单 (豆瓣)
Description: 遗愿清单电影简介和剧情介绍,遗愿清单影评、图片、预告片、影讯、论坛、在线购票
Keywords: 遗愿清单,The Bucket List,遗愿清单影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.200豆瓣电影Top250

# 遗愿清单 The Bucket List (2007)

导演: 罗伯·莱纳
编剧: 贾斯汀·扎克汉姆
主演: 杰克·尼科尔森 / 摩根·弗里曼 / 西恩·海耶斯 / 贝弗利·陶德 / 罗伯·莫洛 / 阿方索·弗里曼 / 罗文娜·金 / 韦尔达·布里奇斯 / 伊恩·安东尼·代尔 / 詹妮弗·迪弗朗西斯科 / 安吉拉·加德纳 / 诺尔·古格雷米 / 乔纳森·赫尔南德斯 / 休·B·赫鲁伯 / 理查德·麦克格纳格尔 / 丸山凯伦 / 安波米德 / 尼基·诺瓦克 / 克里斯托弗·斯塔普勒顿 / 泰勒.安.汤普森 / 亚历克斯·崔贝克 / Annton Berry Jr. / Destiny Brownridge / Brian Copeland / 乔丹·朗德 / Jonathan Mangum / Serena Reeder / MaShae Alderman / Vin Scully
类型: 剧情 / 喜剧 / 冒险
制片国家/地区: 美国
语言: 英语
上映日期: 2007-12-25(多伦多电影节) / 2008-01-11(美国)
片长: 97 分钟
又名: 玩转身前事(港) / 一路玩到挂(台) / 拿命开玩笑 / 乐着活下去
IMDb: tt0825232
豆瓣评分
引用
8.7
425291人评价
5星
47.0%
4星
42.0%
3星
10.3%
2星
0.6%
1星
0.1%
好于 98% 喜剧片
好于 97% 剧情片
想看 看过
评价:
推荐

## 遗愿清单的剧情简介 · · · · · ·

老富翁爱德华•科尔（杰克•尼克尔森 Jack Nicholson 饰）近年来在公立医院的私有化改造事业中获利颇丰，他为节省成本，规定病房“一房两床”的做法颇受非议，但性格强势的科尔不以为意，岂料他不久被检查出罹患癌症，本欲入住单人病房的科尔在舆论压力下只得与另一位病人——老卡特（摩根•弗里曼 Morgan Freeman 饰）同处一室。汽车修理技师老卡特博闻强识，将三个子女培养成才，但代价是牺牲了年轻时要做历史教授的梦想。曾经结婚多次如今却孤身一人的科尔逐渐对卡特产生了兴趣，两位老人在病房中结下了友谊。科尔偶然发现了卡特的“遗愿清单”，他决定运用自己的力量，让那些纸面上的疯狂构想一一实现，去发现人生的真正意义…… ©豆瓣

## 遗愿清单的演职员 · · · · · · ( 全部 45 )

- 罗伯·莱纳 导演
- 杰克·尼科尔森 饰 爱德华·科尔
- 摩根·弗里曼 饰 卡特·钱伯斯
- 西恩·海耶斯 演员
- 贝弗利·陶德 饰 弗吉尼亚·钱伯斯
- 罗伯·莫洛 演员

## 遗愿清单的视频和图片 · · · · · · ( 预告片1 | 添加视频评论 | 图片595 · 添加 )

## 遗愿清单的获奖情况 · · · · · · ( 全部 )

- 第32届日本电影学院奖
- 最佳外语片(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  荒岛余生

  当幸福来敲门

  百万美元宝贝

  肖申克的救赎

  心灵捕手

  阿甘正传

  贫民窟的百万富翁

  国王的演讲

  摔跤吧！爸爸

  叫我第一名

我要写短评

## 遗愿清单的短评 · · · · · · ( 全部 91333 条 )

热门 / 最新 / 好友

### 1237 有用 九尾黑猫 看过 2008-06-24 13:41:30

三流剧本，一流演技，主要是看两个主角啦

### 2981 有用 安东 看过 2010-10-06 22:59:23

前提是：你也得有钱才行啊！

### 2578 有用 Doublebitch 看过 2011-01-04 22:37:16

在电影最后卡特的念白声中，科尔来到女儿家，俯身亲吻美丽的孙女，随后划去“亲吻世上最美的女孩”，我就开始哭，一直哭到电影结束，太温暖了，这个故事仿佛离我很远啊，可我为什么会被感动成这样子。

### 2042 有用 南国玫瑰 看过 2008-12-28 19:39:09

笑了三分之二，最后开始落泪。你亲吻了世界上最美的女孩，你们的故事成为别人见过的最美的传奇。

### 803 有用 米粒 看过 2009-12-28 22:16:25

"Kiss the most beautiful girl in the world." 哭了。。。

> 更多短评 91333条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 遗愿清单的影评 · · · · · · ( 全部 1709 条 )

热门 / 最新 / 好友
简单情节 2008-02-09 03:17:52

## 像今天是末日一样

The Bucket List，中文译名：遗愿清单 前几天在上班的地铁上看到它的预告片，Freeman说，有人在1000个人中间做过一个调查，问你是不是愿意提前知道你准确的死亡时间，答案里面96%的人选择不愿意。我对这种人生类题材的东西一向没有抵抗力，于是回家以后迅速的下载了。 影片讲... (展开)
1897 95 131回应 收起
一湄 2009-02-08 11:51:51

## 当死亡就在前面

两个老头儿。 一个是黑人机械工卡特，话不多，博学，一直梦想当历史教授。 一个是亿万富翁爱德华，社会地位极高，话唠，暴脾气，幽默。 因为癌症，住进了同一间病房。 第一次见面很不友好，爱德华问他的助手汤姆，那他妈是谁啊？卡特接着反问，你他妈是谁？ 慢慢地，习惯了躺在... (展开)
1262 161 72回应 收起
艾小柯 2008-03-08 06:32:28

## 了无遗憾

我向来不爱看极尽煽情的chick flick好莱坞言情喜剧，连带那种让人一眼看破结局基本照煽情路线走的所有温情喜剧都不大喜欢，但这部《遗愿清单》先用强大的演员阵容便把人震住了：杰克·尼科尔森与摩根·弗里曼两位奥斯卡影帝联手压场子，能错到哪儿去？ 片子开场先就让人禁不... (展开)
393 53 85回应 收起
裸奔的鱼 2008-08-10 23:45:13

## 人固有一死，活着的时候快乐就好

这篇影评可能有剧透

生死问题和生活的意义，做为人存在的终极问题，每个人都有自己的答案。在《庄子》上有个故事，曾经坐怀不乱的鲁国大夫柳下惠（季）有个弟弟叫盗跖，他是我国盗贼行业的创始人。据说他有手下九千，横行天下，侵暴诸侯。穴室枢户，驱人牛马，取人妇女。贪得忘亲，不顾父母兄弟，... (展开)
117 16 16回应 收起
是灰小猫啊 2008-09-11 18:38:28

## 最后的三段话

看到最后，听到这三段话的时候哭了。 (Carter) "Dear Edward, I've gone back and forth the last few days, trying to decide whether or not I should even write this. In the end, I realized I would regret it if I didn't, so here goes. I know the last time we saw... (展开)
173 4 18回应 收起
直布罗陀岩石 2008-02-02 16:42:38

## 给自己快乐，给别人快乐，然后告诉上帝

人活着常常夹杂许多遗憾，人活着也有许多的事情需要去做，但如果生命进行到了最后的关头，你还有什么遗憾，还有什么事情需要迫切的去做？是否需要一个清单呢？我们叫这个清单，遗愿清单。 两个老头，阴差阳错住进了同一家医院的同一间病房。一个是富翁，一个是汽车工。两人如... (展开)
127 13 18回应 收起
角島之蛹 2011-03-25 21:04:45

## 笑到哭

我今年大四了，从很小的时候开始，一路奔跑到现在，塞在背包里的那些理想都稀里哗啦地撒了一地。如今拖着越来越轻的背包和越来越重的身体凑合活着。 这让我想到了朴树的那首歌，我们都是很内个的动物，受点委屈，受点罪这么凑合凑合着。当年我觉得我会是一个例外，今天我惊恐地... (展开)
97 1 31回应 收起
坐看云起处 2015-07-29 17:37:30

## 珍惜当下！生如夏花！

看两位实力派演员飙戏，真是太精彩了。尤其是剧本写的真心好。這部笑中带泪的戏，看完后有许多珍贵的东西留在心深处。 如果，生命只剩最后100天，面对这样的问题，你的答案是什麼？列个在死前能实现清单，你想去做什麼事？陪伴什麼人？实现怎样的心愿？ 当我们走过一生... (展开)
37 6 0回应 收起
灵舞魂歌 2012-11-15 23:15:35

## 鸡肋

《遗愿清单》多好的题材，让人浮想联翩：关于生的意义，死的理解，生命不可承受之轻，生活难能可贵的经历······ 不过，看来我是想错了。两位老戏骨中规中矩的表演，类似慢放镜头的场景，平淡无奇的故事，毫无戏剧张力的情节，让人怎么说呢？只能说，别太高看... (展开)
80 51 22回应 收起
May Xue 2020-04-09 10:13:46 #如何解读《遗愿清单》这部电影中，爱德华与卡特的友情？

## 如何解读《遗愿清单》这部电影中，爱德华与卡特的友情？

爱德华与卡特的友情是被救赎者与救赎者的隐喻。此片其实没有摆脱西方影片有关宗教救赎的主题，就如悲惨世界中冉阿让是受到基督教的救赎从一个罪犯成长为一个市长一样，本片通过富翁与穷人难得的共处一间病危病房引发的救赎与被救赎的故事，这里面有对生死的终极追问，也有对人... (展开)
41 1回应 收起

> 更多影评 1709篇

添加新讨论

## 讨论区 · · · · · ·

现在看反而觉得不好看 | 来自柯西玛 |  | 2022-11-19 15:46:33
还好那时没有疫情 | 来自StoneWall | 1 回应 | 2022-11-17 13:10:49
最后一段是谁的独白 | 来自😃 |  | 2022-11-10 13:18:14
女儿为啥生他的气？ | 来自骑士日记 | 7 回应 | 2022-11-04 00:49:09
一只蜗牛该做些什么才能转成更高层次的生命呢？ | 来自probe | 13 回应 | 2022-10-25 09:15:46

> 去这部影片的讨论区（全部195条）

## 关于《遗愿清单》的问题 · · · · · · ( 全部13个 )

- 尼克尔森躺着看电视，带的那种眼镜谁知道是叫什么名字，有卖的吗？ 3人回答
- 骨灰是都放在珠穆朗玛峰了么？ 7人回答

> 全部13个问题

## 在哪儿看这部电影 · · · · · ·

- 腾讯视频 VIP免费观看
- 爱奇艺视频 VIP免费观看
- 哔哩哔哩 VIP免费观看

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 她们都得白血病 (慢先森)
- ★2007-2008 颁奖季★ 获奖影片 (影志)
- 评价人数超过十万的电影 (依然饭特稀)
- 惊艳 (流河夏树)

## 谁在看这部电影 · · · · · ·

- 再见白丝
  刚刚 想看
- -foxiii-
  2分钟前 想看
- keo
  2分钟前 想看

662664人看过 / 274975人想看

订阅遗愿清单的评论:
feed: rss 2.0